/*******************************************************************************
 * Copyright (c) Lenovo 2020.
 *
 *  LIMITED AND RESTRICTED RIGHTS NOTICE: If data or software is delivered
 *  pursuant a General Services Administration (GSA) contract, use, reproduction, or
 *  disclosure is subject to restrictions set forth in Contract No. GS-35F-05925.
 ******************************************************************************/
export declare type Filter = {
    attributes: string[];
    values: string[];
};
declare type FilterObject = Filter[];
/**
 * Builder class to help creating the sorting and filtering complex params
 * https://confluence1.labs.lenovo.com:8443/display/TSM/Sorting+and+Filtering
 */
export declare class SortingAndFilteringParamsBuilder {
    private offset;
    private limit;
    private attributes;
    private filtering;
    private sorting;
    private defaultSorting;
    /**
     * If besides filterContains/filterEquals/sorting/offset/limit and so on we must add another parameter, let's say - type with value unknown, this array should be used as following
     *
     * additionalParams = [ { param: 'type', value: 'unknown' } ]
     */
    private additionalParams;
    get defaultSortingParams(): {
        name: string;
        order: 'asc' | 'desc';
    }[];
    constructor(builder?: SortingAndFilteringParamsBuilder);
    initializeParams(): void;
    initializeFiltering(): void;
    getAdditionalParams(): {
        param: string;
        value: string;
    }[];
    getParams(): string;
    /**
     * Get the filter object
     * @returns filter
     */
    getFiltering(): {
        filterEquals: FilterObject;
        filterContains: FilterObject;
        filterRange: FilterObject;
        filterNotEquals: FilterObject;
        filterNotContains: FilterObject;
    };
    /**
     * Set the offset for the query
     * @param offset
     */
    setOffset(offset: number): this;
    /**
     * Set the limit for the query (how many items should the request fetch)
     * @param limit
     */
    setLimit(limit: number): this;
    /**
     * Method which creates the filtering query string using the filterContains attribute, values provided and attributes.
     *
     * If the attributes array is not provided the filtering will be done considering all attributes.
     * The values array's length does not have to match the attributes array (see the confluence page).
     * The API will ignore any extra query parameters and will only look for the three filters.
     *
     * filterContains: Searches for string values in the specified attributes that have a partial or full match to one or more of the specified values.
     * @param values the values which are used for filtering
     * @param attributes the attributes which are used for filtering
     */
    setFilterContains(values: string[], attributes?: string[]): this;
    /**
     * Method which creates the filtering query string using the filterEquals attribute, values provided and attributes.
     *
     * If the attributes array is not provided the filtering will be done considering all attributes.
     * The values array's length does not have to match the attributes array (see the confluence page).
     *
     * The API will ignore any extra query parameters and will only look for the three filters.
     *
     * filterEquals: Searches for string values in the specified attributes that have a full match to one or more of the specified values.
     * @param values the values which are used for filtering
     * @param attributes the attributes which are used for filtering
     */
    setFilterEquals(values: string[], attributes?: string[]): this;
    /**
     * Method which creates the filtering query string using the filterNotEquals attribute, values provided and attributes.
     *
     * If the attributes array is not provided the filtering will be done considering all attributes.
     * The values array's length does not have to match the attributes array (see the confluence page).
     *
     * The API will ignore any extra query parameters and will only look for the three filters.
     *
     * filterNotEquals:  Excludes the searches for string values in the specified attributes that have a full match to one or more of the specified values.
     * @param values the values which are used for filtering
     * @param attributes the attributes which are used for filtering
     */
    setFilterNotEquals(values: string[], attributes?: string[]): this;
    /**
     * Method which creates the filtering query string using the filterNotEquals attribute, values provided and attributes.
     *
     * If the attributes array is not provided the filtering will be done considering all attributes.
     * The values array's length does not have to match the attributes array (see the confluence page).
     *
     * The API will ignore any extra query parameters and will only look for the three filters.
     *
     * filterNotEquals:  Excludes the searches for string values in the specified attributes that have a full match to one or more of the specified values.
     * @param values the values which are used for filtering
     * @param attributes the attributes which are used for filtering
     */
    setFilterNotContains(values: string[], attributes?: string[]): this;
    /**
     * Method which creates the filtering query string using the filterRange attribute, values provided and attributes.
     *
     * If the attributes array is not provided the filtering will be done considering all attributes.
     * The values array's length does not have to match the attributes array (see the confluence page).
     *
     * The API will ignore any extra query parameters and will only look for the three filters.
     *
     * filterRange: Searches for a range of values on the specified attributes.
     *
     * If val1 is greater than val2, the API should handle this as a range between val2 to val1.
     * Dates need to be in the ISO 8601 format: https://www.w3.org/TR/NOTE-datetime
     * @param values the values which are used for filtering
     * @param attributes the attributes which are used for filtering
     */
    setFilterRange(values: string[], attributes?: string[]): this;
    /**
     * Set the sorting attributes for the query
     * Note: if the sorting parameters array's length is 3 the priorities should only be 0, 1, 2 and they must be specified for all items of the array; the priorities should also not repeat
     *
     * (calling this method will overwrite the previously set sorting)
     * @param sortingParametersAndValues
     */
    setSorting(sortingParametersAndValues: {
        name: string;
        order: 'asc' | 'desc';
    }[]): this;
    /**
     * Set the default sorting attributes for the query which will be applied first and then the other sorting
     * The default sorting is defined in the components and the sorting comes from the user who clicks the table headers
     * Note: if the sorting parameters array's length is 3 the priorities should only be 0, 1, 2 and they must be specified for all items of the array; the priorities should also not repeat
     *
     * (calling this method will overwrite the previously set sorting)
     * @param sortingParametersAndValues
     */
    setDefaultSorting(sortingParametersAndValues: {
        name: string;
        order: 'asc' | 'desc';
    }[]): this;
    /**
     * Set the included attributes (calling this method will overwrite the previously set included attributes)
     * @param includedAttributes attributes which must be included for each object returned
     */
    setIncludeAttributes(includedAttributes: string[]): this;
    /**
     * Set the excluded attributes (calling this method will overwrite the previously set excluded attributes)
     * @param excludedAttributes attributes which must be excluded from each object returned
     */
    setExcludeAttributes(excludedAttributes: string[]): this;
    /**
     * Set the additional attributes (calling this method will overwrite the previously set excluded attributes)
     * @param additionalParams attributes which should be set as additional parameters in the request
     */
    setAdditionalParameters(additionalParams: {
        param: string;
        value: string;
    }[]): this;
    resetParams(): this;
    /**
     * Method used to remove a parameter from the query string
     * If we have filterContains[0][values]=someValue&filterContains[1][values]=someOtherValue this method will remove both of them
     *
     *
     * Use `removeParameterExplicitly('filterContains', [someValue], [])` if you only want to remove the first one
     * @param parameterToRemove 'offset' | 'limit' | 'sort' | 'filterContains' | 'filterRange' | 'filterEquals' | 'includeAttributes' | 'excludeAttributes'
     */
    removeParameter(parameterToRemove: string): this;
    /**
     * Method used to remove a parameter explicitly from the query string. Explicitly means that the parameter which will be removed has the values and the attributes provided as parameters. Works for filterContains, filterRange, filterEquals and filterNotEquals
     *
     *
     * If we have filterContains[0][values]=someValue&filterContains[1][values]=someOtherValue `removeParameter('filterContains')` will remove both of them.
     *
     *
     * Use `removeParameterExplicitly('filterContains', [someValue], [])` if you only want to remove the first one.
     *
     * @param parameterToRemove
     * @param values
     * @param attributes
     */
    removeParameterExplicitly(parameterToRemove: 'filterContains' | 'filterRange' | 'filterEquals' | 'filterNotEquals' | 'filterNotContains', values: string[] | undefined, attributes: string[] | undefined): this;
    parameterExists(parameterToSearchFor: 'filterContains' | 'filterRange' | 'filterEquals' | 'filterNotEquals' | 'filterNotContains', values: string[], attributes: string[]): boolean;
    /**
     * Method which creates the filtering query string by filterType, values provided and attributes. If the attributes array is not provided the filtering will be done considering all attributes.
     * @param filterType can be 'filterContains', 'filterEquals' or 'filterRange'
     * @param values the values which are used for filtering
     * @param attributes the attributes which are used for filtering
     */
    private setFilterAttributesAndValues;
    /**
     * Method which checks if the filter parameter which we are going to add is already set (considering its attributes and values)
     * @param parameter
     * @param values
     * @param attributes
     */
    private checkForFilterDuplicates;
    /**
     * If the user searches for translated 'Not available' then the backend will receive the constant 'NOT_AVAILABLE' and based on this value will return all empty entries for that property (for a column filter) or any property (for a global filter)
     * @param valuesToSearchFor
     */
    checkForNotAvailable(valuesToSearchFor: string[]): void;
}
export {};
